@@ -1,4 +1,7 @@
+/// \file
+///
 /// Flint rational polynomials utilities
+/// ====================================
 /*
    Copyright (C) 2016 Vincent Delecroix
 
@@ -13,10 +16,15 @@
 #ifndef E_ANTIC_FMPQ_POLY_EXTRA_H
 #define E_ANTIC_FMPQ_POLY_EXTRA_H
 
-#include "e-antic.h"
+#include "local.h"
 
 #include <flint/fmpq_poly.h>
+
+#if __FLINT_RELEASE < 30000
 #include <arb.h>
+#else
+#include <flint/arb.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
